@@ -542,6 +542,7 @@ class Beautifier:
                 TOKEN.END_EXPR,
                 TOKEN.WORD,
                 TOKEN.OPERATOR,
+                TOKEN.DOT,
             ]:
                 self._output.space_before_token = True
 
@@ -552,7 +553,7 @@ class Beautifier:
                         self._options.space_before_conditional
                     )
                     next_mode = MODE.ForInitializer
-                elif self._flags.last_token.text in ["if", "while"]:
+                elif self._flags.last_token.text in ["if", "while", "switch"]:
                     self._output.space_before_token = (
                         self._options.space_before_conditional
                     )
@@ -1184,16 +1185,25 @@ class Beautifier:
         self.print_token(current_token)
 
     def handle_string(self, current_token):
-        if self.start_of_statement(current_token):
+        if (
+            current_token.text[0] == "`"
+            and current_token.newlines == 0
+            and current_token.whitespace_before == ""
+            and (
+                self._flags.last_token.type == TOKEN.WORD
+                or current_token.previous.text == ")"
+            )
+        ):
+            # This conditionial checks backtick strings and makes no changes
+            pass
+        elif self.start_of_statement(current_token):
             # The conditional starts the statement if appropriate.
             # One difference - strings want at least a space before
             self._output.space_before_token = True
         else:
             self.handle_whitespace_and_comments(current_token)
-
             if (
-                self._flags.last_token.type == TOKEN.RESERVED
-                or self._flags.last_token.type == TOKEN.WORD
+                self._flags.last_token.type in [TOKEN.RESERVED, TOKEN.WORD]
                 or self._flags.inline_frame
             ):
                 self._output.space_before_token = True
@@ -1205,6 +1215,13 @@ class Beautifier:
             ]:
                 if not self.start_of_object_property():
                     self.allow_wrap_or_preserved_newline(current_token)
+            elif (
+                current_token.text[0] == "`"
+                and self._flags.last_token.type == TOKEN.END_EXPR
+                and current_token.previous.text in ["]", ")"]
+                and current_token.newlines == 0
+            ):
+                self._output.space_before_token = True
             else:
                 self.print_newline()
 
@@ -1440,12 +1457,16 @@ class Beautifier:
             elif self._flags.last_token.type == TOKEN.OPERATOR:
                 # a++ + ++b
                 # a - -b
-                space_before = current_token.text in [
-                    "--",
-                    "-",
-                    "++",
-                    "+",
-                ] and self._flags.last_token.text in ["--", "-", "++", "+"]
+                space_before = (
+                    current_token.text
+                    in [
+                        "--",
+                        "-",
+                        "++",
+                        "+",
+                    ]
+                    and self._flags.last_token.text in ["--", "-", "++", "+"]
+                )
                 # + and - are not unary when preceeded by -- or ++ operator
                 # a-- + b
                 # a * +b
